cordova.define("com.anondesigns.cordova.plugins.audiostreamer", function(require, exports, module) {

// audio stream class for Android
// needs these properties in the manifest: 
// <activity android:launchMode="singleInstance" android:alwaysRetainTaskState="true">

var AudioStreamer = function( playerEl, completeCallback ) {

  var _playing = false;
  var _paused = false;
  var _wasPaused = false;
  var _playTime = 0;
  var _duration = 0;
  var _playbackInterval = null;

  var _audio = null;
  var _controls = null;

  var init = function() {
    // add cache-player controls
    _controls = new cp.CachePlayerConrols( playerEl, controlsDelegate );
    _controls.setLoadedPercent(1);  // normally this would be called while loading, but since we can't seem to get that from the phonegap library, we say that it's fully loaded to make the progress calculations happy
  };

  // update controls on stream progress ----------------------
  var startMonitoringStream = function() {
    // start animation loop to check time and update controls
    if( _playbackInterval != null ) cancelAnimationFrame( _playbackInterval );
    _playbackInterval = requestAnimationFrame( monitorPlayback );
  }

  var monitorPlayback = function() {
    if( _playing && !_paused ) requestAnimationFrame( monitorPlayback );

    var dur = _audio.getDuration();
    if( dur > 0 ) updateDuration(dur);

    _audio.getCurrentPosition(
      function(position) {
        if (position >= 0) updateProgress(position);
      },
      function(e) {
        console.log("Error getting pos=" + e);
      }
    );
  };

  var updateDuration = function(duration) {
      _duration = duration;
      if( duration > 0 ) _controls.setTotalTime( duration * 1000 );
  };

  var updateProgress = function(progress) {
    var lastPlayTime = _playTime;
    _playTime = progress;
    if( ( Math.abs( _playTime - lastPlayTime ) > 0.02 && _paused == false ) || _wasPaused == false ) {
      _wasPaused = false;
      setControlsProgress( _playTime );
      _controls.setBuffering( false );
    }
  };

  var setControlsProgress = function(progress) {
      _controls.setCurTime( progress * 1000 );
  };

  // stream operations -----------------------------
  var playAudio = function(src) {
    if( _audio != null ) {
      _audio.stop();
      _audio.release();
    }
    
    // Create Media object from src and play audio
    _audio = new Media(src, onSuccess, onError, onMediaStatus);
    _audio.play();

    // activate controls
    _controls.setPlaying();
    _controls.setBuffering( true );
    _controls.setCurTime(0);
    
    _paused = false;
    _playing = true;

    // start updating controls
    startMonitoringStream();
  };

  var pauseAudio = function() {
    if (_audio) {
      _paused = !_paused;
      if( _paused ) {
        _playing = false;
        _audio.pause();
      } else {
        _audio.play();
        _playing = true;
        startMonitoringStream();
      }
    }
  };

  var stopAudio = function() {
    if (_audio) {
      _audio.stop();
    }
  };

  // media streaming callbacks ---------------------
  var onMediaStatus = function(status) {
    console.log('status = '+status);
    if( status == Media.MEDIA_STOPPED && completeCallback ) completeCallback();
  };

  var onSuccess = function() {
      console.log("playAudio():Audio Success");
  };

  var onError = function(error) {
    if( error && error.preventDefault ) error.preventDefault(); // prevent errors from killing .js execution...
    if( error && error.stopPropagation ) error.stopPropagation(); 
    console.log('[Phonegap Media Error] code: '    + error.code    + '\n' + 'message: ' + error.message + '\n');
  };

  // controls delegate ----------------------------
  var controlsDelegate = {
    seekTo: function( milliseconds ) {
      if( !_audio ) return;

      _audio.seekTo( milliseconds );
      _audio.play();
      _controls.setBuffering( true ); 

      _wasPaused = true;
      setTimeout(function(){
        _paused = false;
        _playing = true;
        startMonitoringStream();
      }, 300);
    },
    pause: function() {
      _audio.pause();
    },
    // no close or play button in our interface
    play: function() {},
    close: function() {}
  };

  var dispose = function() {
    _controls.dispose();
  };

  // initialization --------------------------------
  init();

  // public interface -----------------------------
  return {
    play: playAudio,
    stop: stopAudio,
    pause: pauseAudio,
    isPaused: function(){ return _paused; },
    dispose: dispose
  };
};
  cordova.addConstructor(function() {
    if(!window.plugins) window.plugins = {};
    window.plugins.AudioStreamer = function(playerEl, completeCallback) {
      var audioStreamer = new AudioStreamer(playerEl, completeCallback);
      return audioStreamer;
    }
  });
});


